@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
-r"""
-This module contains the central operator classes.
+r"""Contains the central operator classes.
 
 See :doc:`Operator overview </code/Operators>`.
 """
@@ -28,23 +27,22 @@ logger = logging.getLogger(__name__)
 
 @nb.njit(cache=True)
 def select_singlet_element(ker, mode0, mode1):
-    """
-    Select element of the singlet matrix
+    """Select element of the singlet matrix.
 
     Parameters
     ----------
-        ker : numpy.ndarray
-            singlet integration kernel
-        mode0 : int
-            id for first sector element
-        mode1 : int
-            id for second sector element
+    ker : numpy.ndarray
+        singlet integration kernel
+    mode0 : int
+        id for first sector element
+    mode1 : int
+        id for second sector element
+
     Returns
     -------
-        ker : complex
-            singlet integration kernel element
+    complex
+        singlet integration kernel element
     """
-
     k = 0 if mode0 == 100 else 1
     l = 0 if mode1 == 100 else 1
     return ker[k, l]
@@ -60,19 +58,18 @@ spec = [
 
 @nb.experimental.jitclass(spec)
 class QuadKerBase:
-    """
-    Manage the common part of Mellin inversion integral
+    """Manage the common part of Mellin inversion integral.
 
     Parameters
     ----------
-        u : float
-            quad argument
-        is_log : boolean
-            is a logarithmic interpolation
-        logx : float
-            Mellin inversion point
-        mode0 : str
-            first sector element
+    u : float
+        quad argument
+    is_log : boolean
+        is a logarithmic interpolation
+    logx : float
+        Mellin inversion point
+    mode0 : str
+        first sector element
     """
 
     def __init__(self, u, is_log, logx, mode0):
@@ -83,30 +80,29 @@ class QuadKerBase:
 
     @property
     def path(self):
-        """Returns the associated instance of :class:`eko.mellin.Path`"""
+        """Return the associated instance of :class:`eko.mellin.Path`."""
         return mellin.Path(self.u, self.logx, self.is_singlet)
 
     @property
     def n(self):
-        """Returns the Mellin moment N"""
+        """Returs the Mellin moment :math:`N`."""
         return self.path.n
 
     def integrand(
         self,
         areas,
     ):
-        """
-        Get transformation to Mellin space integral
+        """Get transformation to Mellin space integral.
 
         Parameters
         ----------
-            areas : tuple
-                basis function configuration
+        areas : tuple
+            basis function configuration
 
         Returns
         -------
-            base_integrand: complex
-                common mellin inversion integrand
+        complex
+            common mellin inversion integrand
         """
         if self.logx == 0.0:
             return 0.0
@@ -265,10 +261,11 @@ class Operator(sv.ModeMixin):
         self._mellin_cut = mellin_cut
         self.is_threshold = is_threshold
         self.op_members = {}
-        self.order = config["order"]
+        self.order = tuple(config["order"])
 
     @property
     def n_pools(self):
+        """Return number of parallel cores."""
         n_pools = self.config["n_integration_cores"]
         if n_pools > 0:
             return n_pools
@@ -277,21 +274,21 @@ class Operator(sv.ModeMixin):
 
     @property
     def fact_to_ren(self):
-        r"""Returns the factor :math:`(\mu_F/\mu_R)^2`"""
+        r"""Return scale variation factor :math:`(\mu_F/\mu_R)^2`."""
         return self.config["fact_to_ren"]
 
     @property
     def int_disp(self):
-        """Returns the interpolation dispatcher"""
+        """Return the interpolation dispatcher."""
         return self.managers["interpol_dispatcher"]
 
     @property
     def grid_size(self):
-        """Returns the grid size"""
+        """Return the grid size."""
         return self.int_disp.xgrid.size
 
     def mur2_shift(self, q2):
-        """Computes shifted renormalization scale.
+        """Compute shifted renormalization scale.
 
         Parameters
         ----------
@@ -309,7 +306,7 @@ class Operator(sv.ModeMixin):
 
     @property
     def a_s(self):
-        """Returns the computed values for :math:`a_s`"""
+        """Return the computed values for :math:`a_s`."""
         sc = self.managers["strong_coupling"]
         a0 = sc.a_s(
             self.mur2_shift(self.q2_from), fact_scale=self.q2_from, nf_to=self.nf
@@ -345,7 +342,7 @@ class Operator(sv.ModeMixin):
         return labels
 
     def quad_ker(self, label, logx, areas):
-        """Partially initialized integrand function.
+        """Return partially initialized integrand function.
 
         Parameters
         ----------
@@ -376,13 +373,13 @@ class Operator(sv.ModeMixin):
             nf=self.nf,
             L=np.log(self.fact_to_ren),
             ev_op_iterations=self.config["ev_op_iterations"],
-            ev_op_max_order=self.config["ev_op_max_order"],
+            ev_op_max_order=tuple(self.config["ev_op_max_order"]),
             sv_mode=self.sv_mode,
             is_threshold=self.is_threshold,
         )
 
     def initialize_op_members(self):
-        """Init all ops with identity or zeros if we skip them"""
+        """Init all operators with the identity or zeros."""
         eye = OpMember(
             np.eye(self.grid_size), np.zeros((self.grid_size, self.grid_size))
         )
@@ -401,7 +398,7 @@ class Operator(sv.ModeMixin):
         self,
         log_grid,
     ):
-        """Run the integration for each grid point
+        """Run the integration for each grid point.
 
         Parameters
         ----------
@@ -412,7 +409,6 @@ class Operator(sv.ModeMixin):
         -------
         list
             computed operators at the give grid point
-
         """
         column = []
         k, logx = log_grid
@@ -435,7 +431,6 @@ class Operator(sv.ModeMixin):
                 )
                 temp_dict[label] = res[:2]
             column.append(temp_dict)
-
         logger.info(
             "%s: computing operators - %u/%u took: %6f s",
             self.log_label,
@@ -449,13 +444,19 @@ class Operator(sv.ModeMixin):
         """Compute the actual operators (i.e. run the integrations)."""
         self.initialize_op_members()
 
-        # skip computation ?
+        # skip computation?
         if np.isclose(self.q2_from, self.q2_to):
-            logger.info(
-                "%s: skipping unity operator at %e", self.log_label, self.q2_from
-            )
-            self.copy_ns_ops()
-            return
+            # unless we have to do some scale variation
+            # TODO remove if K is factored out of here
+            if not (
+                self.sv_mode == sv.Modes.expanded
+                and not np.isclose(self.fact_to_ren, 1.0)
+            ):
+                logger.info(
+                    "%s: skipping unity operator at %e", self.log_label, self.q2_from
+                )
+                self.copy_ns_ops()
+                return
 
         logger.info(
             "%s: computing operators %e -> %e, nf=%d",
@@ -470,7 +471,7 @@ class Operator(sv.ModeMixin):
             self.mur2_shift(self.q2_from),
             self.mur2_shift(self.q2_to),
         )
-        if self.sv_mode.name != "unvaried":
+        if self.sv_mode != sv.Modes.unvaried:
             logger.info(
                 "Scale Variation: (µ_F/µ_R)^2 = %e, mode: %s",
                 self.fact_to_ren,
@@ -494,12 +495,12 @@ class Operator(sv.ModeMixin):
     def integrate(
         self,
     ):
-        """Run the integration"""
+        """Run the integration."""
         tot_start_time = time.perf_counter()
 
         # run integration in parallel for each grid point
         # or avoid opening a single pool
-        args = (self.run_op_integration, enumerate(np.log(self.int_disp.xgrid_raw)))
+        args = (self.run_op_integration, enumerate(np.log(self.int_disp.xgrid.raw)))
         if self.n_pools == 1:
             res = map(*args)
         else:
@@ -521,7 +522,7 @@ class Operator(sv.ModeMixin):
         )
 
     def copy_ns_ops(self):
-        """Copy non-singlet kernels, if necessary"""
+        """Copy non-singlet kernels, if necessary."""
         if self.order[0] == 1:  # in LO +=-=v
             for label in ["nsV", "ns-"]:
                 self.op_members[
