@@ -21,14 +21,33 @@ logger = logging.getLogger(__name__)
 
 
 class OperatorGrid(sv.ModeMixin):
-    """
+    """Collection of evolution operators for several scales.
+
     The operator grid is the driver class of the evolution.
 
     It receives as input a threshold holder and a generator of a_s.
     From that point onwards it can compute any operator at any q2.
 
-    Parameters
+    Attributes
     ----------
+    config: dict
+    q2_grid: np.ndarray
+    managers: dict
+
+    """
+
+    def __init__(
+        self,
+        config,
+        q2_grid,
+        thresholds_config,
+        strong_coupling,
+        interpol_dispatcher,
+    ):
+        """Initialize `OperatorGrid`.
+
+        Parameters
+        ----------
         config: dict
             configuration dictionary
         q2_grid: array
@@ -44,20 +63,12 @@ class OperatorGrid(sv.ModeMixin):
         kernel_dispatcher: eko.kernel_generation.KernelDispatcher
             Instance of the :class:`~eko.kernel_generation.KernelDispatcher` with the
             information about the kernels
-    """
 
-    def __init__(
-        self,
-        config,
-        q2_grid,
-        thresholds_config,
-        strong_coupling,
-        interpol_dispatcher,
-    ):
+        """
         # check
         order = config["order"]
         method = config["method"]
-        if not method in [
+        if method not in [
             "iterate-exact",
             "iterate-expanded",
             "truncated",
@@ -119,13 +130,13 @@ class OperatorGrid(sv.ModeMixin):
         }
         method = mod_ev2method.get(method, method)
         config["method"] = method
-        config["backward_inversion"] = operators_card["backward_inversion"]
+        config["backward_inversion"] = operators_card["configs"]["backward_inversion"]
         config["fact_to_ren"] = (theory_card["fact_to_ren_scale_ratio"]) ** 2
-        config["ev_op_max_order"] = operators_card["ev_op_max_order"]
-        config["ev_op_iterations"] = operators_card["ev_op_iterations"]
-        config["debug_skip_singlet"] = operators_card["debug_skip_singlet"]
-        config["debug_skip_non_singlet"] = operators_card["debug_skip_non_singlet"]
-        config["n_integration_cores"] = operators_card["n_integration_cores"]
+        config["ev_op_max_order"] = operators_card["configs"]["ev_op_max_order"]
+        config["ev_op_iterations"] = operators_card["configs"]["ev_op_iterations"]
+        config["n_integration_cores"] = operators_card["configs"]["n_integration_cores"]
+        config["debug_skip_singlet"] = operators_card["debug"]["skip_singlet"]
+        config["debug_skip_non_singlet"] = operators_card["debug"]["skip_non_singlet"]
         config["HQ"] = theory_card["HQ"]
         config["ModSV"] = theory_card["ModSV"]
         q2_grid = np.array(operators_card["Q2grid"], np.float_)
@@ -203,7 +214,7 @@ class OperatorGrid(sv.ModeMixin):
         return thr_ops
 
     def compute(self, q2grid=None):
-        """Computes all ekos for the `q2grid`.
+        """Compute all ekos for the `q2grid`.
 
         Parameters
         ----------
@@ -234,7 +245,7 @@ class OperatorGrid(sv.ModeMixin):
         return grid_return
 
     def generate(self, q2):
-        r"""Computes a single EKO.
+        r"""Compute a single EKO.
 
         Parameters
         ----------
@@ -297,6 +308,6 @@ class OperatorGrid(sv.ModeMixin):
 
         values, errors = final_op.to_flavor_basis_tensor()
         return {
-            "operators": values,
-            "operator_errors": errors,
+            "operator": values,
+            "error": errors,
         }
