@@ -8,9 +8,11 @@ to evaluate the interpolator.
 """
 import logging
 import math
+from typing import Sequence, Union
 
 import numba as nb
 import numpy as np
+import numpy.typing as npt
 import scipy.special as sp
 
 logger = logging.getLogger(__name__)
@@ -414,6 +416,66 @@ class BasisFunction:
         return self.callable(*args, **kwargs)
 
 
+class XGrid:
+    def __init__(self, xgrid: Union[Sequence, npt.NDArray], log: bool = True):
+        ugrid = np.array(np.unique(xgrid), np.float_)
+        if len(xgrid) != len(ugrid):
+            raise ValueError(f"xgrid is not unique: {xgrid}")
+        if len(xgrid) < 2:
+            raise ValueError(f"xgrid needs at least 2 points, received {len(xgrid)}")
+
+        self.log = log
+
+        # henceforth ugrid might no longer be the input!
+        # which is ok, because for most of the code this is all we need to do
+        # to distinguish log and non-log
+        if log:
+            self._raw = ugrid
+            ugrid = np.log(ugrid)
+
+        self.grid = ugrid
+
+    def __len__(self) -> int:
+        return len(self.grid)
+
+    def __eq__(self, other) -> bool:
+        """Checks equality"""
+        # check shape before comparing values
+        return len(self) == len(other) and np.allclose(self.raw, other.raw)
+
+    @property
+    def raw(self) -> np.ndarray:
+        return self.grid if not self.log else self._raw
+
+    @property
+    def size(self) -> int:
+        return self.grid.size
+
+    def tolist(self) -> list:
+        return self.raw.tolist()
+
+    def dump(self) -> dict:
+        return dict(grid=self.tolist(), log=self.log)
+
+    @classmethod
+    def load(cls, doc: dict):
+        return cls(doc["grid"], log=doc["log"])
+
+    @classmethod
+    def fromcard(cls, value: list, log: bool):
+        if len(value) == 0:
+            raise ValueError("Empty xgrid!")
+
+        if value[0] == "make_grid":
+            xgrid = make_grid(*value[1:])
+        elif value[0] == "make_lambert_grid":
+            xgrid = make_lambert_grid(*value[1:])
+        else:
+            xgrid = np.array(value)
+
+        return cls(xgrid, log=log)
+
+
 class InterpolatorDispatcher:
     """
     Setups the interpolator.
@@ -426,7 +488,7 @@ class InterpolatorDispatcher:
 
     Parameters
     ----------
-        xgrid_in : numpy.ndarray
+        xgrid : numpy.ndarray
             Grid in x-space from which the interpolators are constructed
         polynomial_degree : int
             degree of the interpolation polynomial
@@ -436,41 +498,32 @@ class InterpolatorDispatcher:
             if true compiles the function on N, otherwise compiles x
     """
 
-    def __init__(self, xgrid, polynomial_degree, log=True, mode_N=True):
+    def __init__(
+        self, xgrid: Union[XGrid, Sequence, npt.NDArray], polynomial_degree, mode_N=True
+    ):
+        if not isinstance(xgrid, XGrid):
+            xgrid = XGrid(xgrid)
+
         # sanity checks
-        xgrid_size = len(xgrid)
-        ugrid = np.array(np.unique(xgrid), np.float_)
-        if xgrid_size != len(ugrid):
-            raise ValueError(f"xgrid is not unique: {xgrid}")
-        xgrid = ugrid
-        if xgrid_size < 2:
-            raise ValueError(f"xgrid needs at least 2 points, received {xgrid_size}")
         if polynomial_degree < 1:
             raise ValueError(
                 f"need at least polynomial_degree 1, received {polynomial_degree}"
             )
-        if xgrid_size <= polynomial_degree:
+        if len(xgrid) <= polynomial_degree:
             raise ValueError(
                 f"to interpolate with degree {polynomial_degree} "
                 " we need at least that much points + 1"
             )
-        # keep a true copy of grid
-        self.xgrid_raw = xgrid
-        # henceforth xgrid might no longer be the input!
-        # which is ok, because for most of the code this is all we need to do
-        # to distinguish log and non-log
-        if log:
-            xgrid = np.log(xgrid)
 
         # Save the different variables
         self.xgrid = xgrid
         self.polynomial_degree = polynomial_degree
-        self.log = log
+        self.log = xgrid.log
         logger.info(
             "Interpolation: number of points = %d, polynomial degree = %d, logarithmic = %s",
-            xgrid_size,
+            len(xgrid),
             polynomial_degree,
-            log,
+            xgrid.log,
         )
 
         # Create blocks
@@ -482,76 +535,32 @@ class InterpolatorDispatcher:
         if polynomial_degree % 2 == 0:
             po2 -= 1
         # iterate areas: there is 1 less then number of points
-        for i in range(xgrid_size - 1):
+        for i in range(len(xgrid) - 1):
             kmin = max(0, i - po2)
             kmax = kmin + polynomial_degree
-            if kmax >= xgrid_size:
-                kmax = xgrid_size - 1
+            if kmax >= len(xgrid):
+                kmax = len(xgrid) - 1
                 kmin = kmax - polynomial_degree
             b = (kmin, kmax)
             list_of_blocks.append(b)
 
         # Generate the basis functions
         basis_functions = []
-        for i in range(xgrid_size):
+        for i in range(len(xgrid)):
             new_basis = BasisFunction(
-                xgrid, i, list_of_blocks, mode_log=log, mode_N=mode_N
+                xgrid.grid, i, list_of_blocks, mode_log=xgrid.log, mode_N=mode_N
             )
             basis_functions.append(new_basis)
         self.basis = basis_functions
 
-    @classmethod
-    def from_dict(cls, operators_card, mode_N=True):
-        """
-        Create object from dictionary.
-
-        .. list-table:: operators runcard parameters
-            :header-rows: 1
-
-            *   - Name
-                - Type
-                - description
-            *   - ``interpolation_xgrid``
-                - :py:obj:`list(float)`
-                - the interpolation grid
-            *   - ``interpolation_polynomial_degree``
-                - :py:obj:`int`
-                - polynomial degree of the interpolating function
-            *   - ``interpolation_is_log``
-                - :py:obj:`bool`
-                - use logarithmic interpolation?
-
-        Parameters
-        ----------
-            operators_card : dict
-                input configurations
-        """
-        # load xgrid
-        xgrid = operators_card["interpolation_xgrid"]
-        if len(xgrid) == 0:
-            raise ValueError("Empty xgrid!")
-        if xgrid[0] == "make_grid":
-            xgrid = make_grid(*xgrid[1:])
-        elif xgrid[0] == "make_lambert_grid":
-            xgrid = make_lambert_grid(*xgrid[1:])
-        is_log_interpolation = bool(operators_card["interpolation_is_log"])
-        polynom_rank = operators_card["interpolation_polynomial_degree"]
-        return cls(
-            xgrid,
-            polynom_rank,
-            log=is_log_interpolation,
-            mode_N=mode_N,
-        )
-
     def __eq__(self, other):
         """Checks equality"""
         checks = [
-            len(self.xgrid_raw) == len(other.xgrid_raw),
             self.log == other.log,
             self.polynomial_degree == other.polynomial_degree,
+            self.xgrid == other.xgrid,
         ]
-        # check elements after shape
-        return all(checks) and np.allclose(self.xgrid_raw, other.xgrid_raw)
+        return all(checks)
 
     def __iter__(self):
         # return iter(self.basis)
@@ -561,7 +570,7 @@ class InterpolatorDispatcher:
     def __getitem__(self, item):
         return self.basis[item]
 
-    def get_interpolation(self, targetgrid):
+    def get_interpolation(self, targetgrid: Union[npt.NDArray, Sequence]):
         """Computes interpolation matrix between `targetgrid` and `xgrid`.
 
         .. math::
@@ -581,10 +590,10 @@ class InterpolatorDispatcher:
 
         """
         # trivial?
-        if len(targetgrid) == len(self.xgrid_raw) and np.allclose(
-            targetgrid, self.xgrid_raw
+        if len(targetgrid) == len(self.xgrid) and np.allclose(
+            targetgrid, self.xgrid.raw
         ):
-            return np.eye(len(self.xgrid_raw))
+            return np.eye(len(self.xgrid))
         # compute map
         out = []
         for x in targetgrid:
@@ -607,9 +616,9 @@ class InterpolatorDispatcher:
                 full grid configuration
         """
         ret = {
-            "interpolation_xgrid": self.xgrid_raw,
-            "interpolation_polynomial_degree": self.polynomial_degree,
-            "interpolation_is_log": self.log,
+            "xgrid": self.xgrid.dump(),
+            "polynomial_degree": self.polynomial_degree,
+            "is_log": self.log,
         }
         return ret
 
