@@ -1,7 +1,5 @@
 # -*- coding: utf-8 -*-
-"""
-Operator card configurations.
-"""
+"""Operator card configurations."""
 from banana.data import cartesian_product, sql
 
 from eko import interpolation
@@ -9,19 +7,26 @@ from eko import interpolation
 from . import db
 
 default_card = dict(
-    interpolation_xgrid=interpolation.make_grid(30, 20).tolist(),
-    interpolation_polynomial_degree=4,
-    interpolation_is_log=True,
-    debug_skip_non_singlet=False,
-    debug_skip_singlet=False,
-    ev_op_max_order=10,
-    ev_op_iterations=10,
-    backward_inversion="expanded",
-    n_integration_cores=0,
-    Q2grid=[100],
+    sorted(
+        dict(
+            interpolation_xgrid=interpolation.make_grid(30, 20).tolist(),
+            interpolation_polynomial_degree=4,
+            interpolation_is_log=True,
+            ev_op_max_order=10,
+            ev_op_iterations=10,
+            backward_inversion="expanded",
+            n_integration_cores=0,
+            debug_skip_non_singlet=False,
+            debug_skip_singlet=False,
+            Q2grid=[100],
+            inputgrid=None,
+            targetgrid=None,
+            inputpids=None,
+            targetpids=None,
+        ).items()
+    )
 )
 
-default_card = dict(sorted(default_card.items()))
 
 lhapdf_config = {
     # "ev_op_max_order": [10],
@@ -50,7 +55,7 @@ pegasus_exact_config = {
 
 def build(update=None):
     """
-    Generate all operator card updates
+    Generate all operator card updates.
 
     Parameters
     ----------
