@@ -2,10 +2,13 @@
 """
 ekomark specialization of the navigator
 """
+import argparse
+import pathlib
+
 from banana import cfg as banana_cfg
 from banana import navigator as bnav
 
-from . import navigator
+from . import glob, navigator
 
 
 def yelp(*args):
@@ -35,21 +38,35 @@ Available functions:
     return None
 
 
-h = yelp
+def register_globals(configpath):
+    app = navigator.NavigatorApp(configpath, "sandbox")
+    glob.app = app
 
-app = navigator.NavigatorApp(banana_cfg.cfg, "sandbox")
+    glob.glob["yelp"] = yelp
+    glob.glob["h"] = yelp
 
-# register banana functions
-bnav.register_globals(globals(), app)
+    # register banana functions
+    bnav.register_globals(glob.glob, glob.app)
 
-# add my functions
-dfl = app.log_as_dfd
-check_log = app.check_log
-plot_pdfs = app.plot_pdfs
-display_pdfs = app.display_pdfs
-compare = app.compare_external
+    # add my functions
+    glob.glob["check_log"] = app.check_log
+    glob.glob["plot_pdfs"] = app.plot_pdfs
+    glob.glob["display_pdfs"] = app.display_pdfs
 
 
 def launch_navigator():
     """CLI Entry point"""
-    return bnav.launch_navigator("eko", "ekomark")
+    parser = argparse.ArgumentParser()
+
+    parser.add_argument(
+        "-c", "--config", type=pathlib.Path, default=None, help="Path to config file"
+    )
+
+    args = parser.parse_args()
+
+    register_globals(banana_cfg.detect(args.config))
+
+    # ekomark.navigator makes the globals here (e.g. app, ls, t) available inside IPython
+    return bnav.launch_navigator(
+        ["eko", "ekomark", "ekomark.navigator.glob"], skip_cfg=True
+    )
